package org.firstinspires.ftc.teamcode;

import com.acmerobotics.roadrunner.SleepAction;
import com.qualcomm.robotcore.eventloop.opmode.Autonomous;
import com.qualcomm.robotcore.eventloop.opmode.OpMode;
import com.qualcomm.robotcore.util.ElapsedTime;

import org.firstinspires.ftc.teamcode.pedroPathing.follower.Follower;
import org.firstinspires.ftc.teamcode.subsystems.ArmSubsystem;
import org.firstinspires.ftc.teamcode.subsystems.ClawSubsystem;
import org.firstinspires.ftc.teamcode.subsystems.DualMotorSliderSubsystem;
import org.firstinspires.ftc.teamcode.subsystems.HangMotorSubsystem;
import org.firstinspires.ftc.teamcode.subsystems.WristSubsystem;

@Autonomous(name = "Specimen Auto", group = "Development")

public class SpecimenAuto extends OpMode {
    private Follower follower;
    private int state;
    private ElapsedTime runtime;

    private DualMotorSliderSubsystem lift;
    private ClawSubsystem claw;
    private WristSubsystem wrist;
    private ArmSubsystem arm;
    private HangMotorSubsystem hang;



    @Override
     public void init(){
         lift = new DualMotorSliderSubsystem(hardwareMap);
         claw = new ClawSubsystem(hardwareMap);
         arm = new ArmSubsystem(hardwareMap);
         wrist = new WristSubsystem(hardwareMap);
         hang = new HangMotorSubsystem(hardwareMap);
         follower = new Follower(hardwareMap);
         runtime = new ElapsedTime();

         state = 0;
         lift.init();
         claw.init();
         wrist.InitAuto();
         arm.initAuto();


        follower.setMaxPower(.45);


     }

    @Override
    public void loop() {
        if(runtime != null){
            telemetry.addData("Runtime (seconds)", runtime.seconds());
        }
        telemetry.addData("state", state);
         switch(state) {
             case 0:
                 runtime.reset();
                 wrist.toSpecimenPrep();
                 arm.toSpecimenPrep();
                 if(runtime.seconds() > 0.25){state = 1;}
                 break;
             case 1:
                 //line 1
                 if(runtime.seconds() > 3){state = 2;}
                 break;
             case 2:
                 lift.toSpecimanHangHeight();
                 if(runtime.seconds() > 3.75){state = 3;}
                 break;
             case 3:
                wrist.toSpecimenHang();
                 if(runtime.seconds() > 4){state = 4;}
                 break;
             case 4:
                lift.toSpecimanReleaseHeight();
                 if(runtime.seconds() > 4.5){state = 5;}
                 break;
             case 5:
                 claw.switchState();
                 if(runtime.seconds() > 4.65){state = 6;}
                 break;
             case 6:
                 lift.toFloorPosition();
                 if(runtime.seconds() > 4.75){state = 7;}
                 break;
             case 7:
                 arm.toParkPosition();
                 wrist.toTravelPosition();
                 //line 2
                 if(runtime.seconds() > 0.){state = 8;}
                 break;
             case 8:
                 if(runtime.seconds() > 0.25){state = 9;}
                 break;
             case 9:
                 //specimen drop
                 break;
             case 10:
                 //path 6
                 break;
             case 11:
                 //specimen pickup
                 break;
             case 12:
                 //path 7
                 break;
             case 13:
                 //specimen drop
                 break;
         }
         new SleepAction(5);
    }

}
